@@ -31,7 +31,7 @@ class Client(object):
     TIMEOUT_KEY = 'timeout'
     TIMEOUT_DEFAULT = 15.0
     # Format: client/client_version/endpoint/endpoint_version/system/release
-    USER_AGENT = ('pypureclient/1.3.0/Pure1/1.0/{sys}/{rel}'
+    USER_AGENT = ('pypureclient/1.4.0/Pure1/1.0/{sys}/{rel}'
                   .format(sys=platform.system(), rel=platform.release()))
 
     def __init__(self, **kwargs):
@@ -215,6 +215,52 @@ class Client(object):
         _process_kwargs(kwargs, list_params, quoted_params)
         return self._call_api(endpoint, kwargs)
 
+    def get_arrays_support_contracts(self, resources=None, **kwargs):
+        """
+        Retrieves the support contracts associated with arrays.
+
+        Args:
+            resources (list[FixedReference], optional):
+                A list of resources to query for. Overrides resource_ids and resource_names keyword arguments.
+
+        Keyword args:
+            x_request_id (str, optional):
+                A header to provide to track the API call. Generated by the server if not
+                provided.
+            continuation_token (str, optional):
+                An opaque token to iterate over a collection of resources.
+            filter (Filter, optional):
+                A filter to include only resources that match the specified criteria.
+            limit (int, optional):
+                Limit the number of resources in the response. If not specified, defaults to
+                1000.
+            offset (int, optional):
+                The offset of the first resource to return from a collection.
+            resource_ids (list[str], optional):
+                A list of resource IDs. If there is not at least one resource that matches each
+                of the elements of names, an error is returned.
+            resource_names (list[str], optional):
+                A list of resource names. If there is not at least one resource that matches
+                each of the elements of names, an error is returned.
+            sort (list[Property], optional):
+                Sort the response by the specified Properties. Can also be a single element.
+
+        Returns:
+            ValidResponse: If the call was successful.
+            ErrorResponse: If the call was not successful.
+
+        Raises:
+            PureError: If calling the API fails.
+            ValueError: If a parameter is of an invalid type.
+            TypeError: If invalid or missing parameters are used.
+        """
+        endpoint = self._arrays_api.api10_arrays_support_contracts_get_with_http_info
+        _process_references(resources, ['resource_ids', 'resource_names'], kwargs)
+        list_params = ['resource_ids', 'resource_names', 'sort']
+        quoted_params = ['continuation_token', 'resource_ids', 'resource_names']
+        _process_kwargs(kwargs, list_params, quoted_params)
+        return self._call_api(endpoint, kwargs)
+
     def put_arrays_tags(self, resources=None, **kwargs):
         """
         Creates or updates array tags contextual to Pure1 only.
